# resumeassistant
The resume assistant is your own personal AI assistant that builds a mega resume in the background using all your skills, experience, and certifications. 

You can build the mega resume by using the resume screening function and answering all the missing information over time. 

Empowered with the latest GPT-based models, the resume assistant uses the information from your mega resume in the background to build a custom CV and cover letter that fits the job description. 

## Datasets
Datasets used for sample candidate resumes: 
[Resumes-Images-Datasets](https://www.kaggle.com/datasets/youssefkhalil/resumes-images-datasets)

## Installation 
To use, install this library run
```bash
pip install resumeassistant
```

## Example
An example of implementation is provided in the jupyter notebook [process.ipynb](https://github.com/harish2sista/resumeassistant/blob/main/process.ipynb)
